@@ -1,10 +1,10 @@
 package Perinci::Sub::To::FuncBase;
 
-our $DATE = '2015-07-07'; # DATE
-our $VERSION = '0.61'; # VERSION
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.62'; # VERSION
 
 use 5.010;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 use Moo;
 
 use Data::Dump::OneLine qw(dump1);
@@ -191,7 +191,7 @@ Perinci::Sub::To::FuncBase - Base class for Perinci::Sub::To::* function documen
 
 =head1 VERSION
 
-This document describes version 0.61 of Perinci::Sub::To::FuncBase (from Perl distribution Perinci-To-Doc), released on 2015-07-07.
+This document describes version 0.62 of Perinci::Sub::To::FuncBase (from Perl distribution Perinci-To-Doc), released on 2015-08-18.
 
 =for Pod::Coverage .+
 
