@@ -1,10 +1,10 @@
 package Perinci::To::Doc::Role::Section;
 
-our $DATE = '2015-07-07'; # DATE
-our $VERSION = '0.61'; # VERSION
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.62'; # VERSION
 
 use 5.010;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 use Moo::Role;
 
 has doc_sections => (is=>'rw');
@@ -111,7 +111,7 @@ Perinci::To::Doc::Role::Section - Role for class that generates documentation wi
 
 =head1 VERSION
 
-This document describes version 0.61 of Perinci::To::Doc::Role::Section (from Perl distribution Perinci-To-Doc), released on 2015-07-07.
+This document describes version 0.62 of Perinci::To::Doc::Role::Section (from Perl distribution Perinci-To-Doc), released on 2015-08-18.
 
 =head1 DESCRIPTION
 
