@@ -1,10 +1,10 @@
 package Perinci::To::POD;
 
-our $DATE = '2015-07-07'; # DATE
-our $VERSION = '0.61'; # VERSION
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.62'; # VERSION
 
 use 5.010001;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 use Moo;
 
 use Locale::TextDomain::UTF8 'Perinci-To-Doc';
@@ -153,7 +153,7 @@ Perinci::To::POD - Generate POD documentation for a package from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.61 of Perinci::To::POD (from Perl distribution Perinci-To-Doc), released on 2015-07-07.
+This document describes version 0.62 of Perinci::To::POD (from Perl distribution Perinci-To-Doc), released on 2015-08-18.
 
 =head1 SYNOPSIS
 
