@@ -1,11 +1,11 @@
 package Perinci::To::PackageBase;
 
-our $DATE = '2015-07-07'; # DATE
-our $VERSION = '0.61'; # VERSION
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.62'; # VERSION
 
 use 5.010;
 use Data::Dump::OneLine qw(dump1);
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 use Moo;
 use Perinci::Object;
 
@@ -120,7 +120,7 @@ Perinci::To::PackageBase - Base class for Perinci::To::* package documentation g
 
 =head1 VERSION
 
-This document describes version 0.61 of Perinci::To::PackageBase (from Perl distribution Perinci-To-Doc), released on 2015-07-07.
+This document describes version 0.62 of Perinci::To::PackageBase (from Perl distribution Perinci-To-Doc), released on 2015-08-18.
 
 =for Pod::Coverage .+
 
